==> Amino_new.py-1.2.17.tar.gz: Amino_new.py-1.2.17/README.md <==
[//]: # (**README Improved By ODYSS3EUS**)
[//]: # (Never Underestimate Presentation)

<h1 align="center">
  <br>
  <a href="https://github.com/aminobot22/MAmino.py"><img src="https://discord.com/channels/868758038587260969/868914322817036329/883176801294237756.png?size=512" alt="Amino_new.py" width="200"></a>
  <br>
  Amino_new
  <br>
</h1>


#### What Is This?
MAmino.py Is A Python API For Communicating With Amino Servers Whilst Pretending That You're An App User. This Is Mostly Accomplished By Spoofing Device Configuration Headers. It Is Also For Objectifying And Organizing Amino Response Data, So That Actually Doing Anything Is Easier.

### API Reference
Read The Docs: [Link Here](https://aminopy.readthedocs.io/en/latest/)

#### How do I use this?
You'll Need Python 3 To Use This Library, I Recommend Using Python 3.6 Or Earlier.
To Install It Just Open The Command Line And Type This Command `python3 -m pip install MAmino.py`
- **NOTE:** MAKE SURE YOU TYPE `Amino_new` **NOT** `Amino` AS IT WILL INSTALL THE **WRONG** PACKAGE UNINSTALL Amino.py!

#### Pip Not Working?
0. Make Sure Pip Is Installed See: [How To Set-Up Pip](https://nitratine.net/blog/post/how-to-setup-pythons-pip/) 
1. Alternatively Download The API [HERE](https://github.com/Slimakoi/Amino.py/archive/refs/heads/master.zip)
2. Extract The .zip File Either With [Winrar](https://www.win-rar.com/download.html?&L=0) or [7zip](https://www.7-zip.org/download.html)
3. Open The Extracted Folder In An [IDE](https://visualstudio.microsoft.com/downloads/) Of Your Choosing
And Navigate To The Folder Named `Amino_new-master`
4. Select The Python Interpreter
5. Make A New `*.py` File And Start Creating 

[//]: # (*Verbose Instructions For Those Who Want To Start Programming But Don't Know How.)

#### If You Have Any Questions Join Us On Discord: https://discord.gg/mMNJmrKMgw

==> Amino_new.py-4.7.tar.gz: Amino_new.py-4.7/README.md <==
[//]: # (**README Improved By ODYSS3EUS**)
[//]: # (Never Underestimate Presentation)

<h1 align="center">
  <br>
  <a href="https://github.com/aminobot22/MAmino.py"><img src="https://i.imgur.com/LLzB0nxt.png?size=512" alt="Amino_new.py" width="200"></a>
  <br>
  Amino_new
  <br>
</h1>


#### What Is This?
MAmino.py Is A Python API For Communicating With Amino Servers Whilst Pretending That You're An App User. This Is Mostly Accomplished By Spoofing Device Configuration Headers. It Is Also For Objectifying And Organizing Amino Response Data, So That Actually Doing Anything Is Easier.

### API Reference
Read The Docs: [Link Here](https://aminopy.readthedocs.io/en/latest/)

#### How do I use this?
You'll Need Python 3 To Use This Library, I Recommend Using Python 3.6 Or Earlier.
To Install It Just Open The Command Line And Type This Command `python3 -m pip install MAmino.py`
- **NOTE:** MAKE SURE YOU TYPE `Amino_new` **NOT** `Amino` AS IT WILL INSTALL THE **WRONG** PACKAGE UNINSTALL Amino.py!

#### Pip Not Working?
0. Make Sure Pip Is Installed See: [How To Set-Up Pip](https://nitratine.net/blog/post/how-to-setup-pythons-pip/) 
1. Alternatively Download The API [HERE](https://github.com/Slimakoi/Amino.py/archive/refs/heads/master.zip)
2. Extract The .zip File Either With [Winrar](https://www.win-rar.com/download.html?&L=0) or [7zip](https://www.7-zip.org/download.html)
3. Open The Extracted Folder In An [IDE](https://visualstudio.microsoft.com/downloads/) Of Your Choosing
And Navigate To The Folder Named `Amino_new-master`
4. Select The Python Interpreter
5. Make A New `*.py` File And Start Creating 

[//]: # (*Verbose Instructions For Those Who Want To Start Programming But Don't Know How.)

#### If You Have Any Questions Join Us On Discord: https://discord.gg/mMNJmrKMgw
